# coffeepy

Coffeepy ☕️ prevents the system from sleeping.

## Installation

```sh
pip install coffeepy
```

## Usage

Simply run the program from command line
```sh
coffeepy
```

By default the program runs indefinitely. Press `Ctrl-C` to quit

Optional: You can set the time in minutes with `-t` flag. To run the program for 1 hour, use

```sh
coffeepy -t 60
```


## License

This project is licensed under the MIT [License](https://github.com/kuvaus/coffeepy/blob/main/LICENSE)


